summaryrefslogtreecommitdiffstats
path: root/kppp/modemdb.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kppp/modemdb.cpp
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kppp/modemdb.cpp')
-rw-r--r--kppp/modemdb.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/kppp/modemdb.cpp b/kppp/modemdb.cpp
index 11b25b9c..74488dca 100644
--- a/kppp/modemdb.cpp
+++ b/kppp/modemdb.cpp
@@ -42,7 +42,7 @@
#include <kconfig.h>
#include <kstdguiitem.h>
-ModemSelector::ModemSelector(TQWidget *parent) : TQDialog(parent, 0, true) {
+ModemSelector::ModemSelector(TQWidget *tqparent) : TQDialog(tqparent, 0, true) {
// set up widgets and such
setCaption(i18n("Select Modem Type"));
TQVBoxLayout *tl = new TQVBoxLayout(this, 10, 10);
@@ -51,7 +51,7 @@ ModemSelector::ModemSelector(TQWidget *parent) : TQDialog(parent, 0, true) {
"right list. If you don't know which modem you have, "
"you can try out one of the \"Generic\" modems."),
this);
- l1->setAlignment(AlignLeft | WordBreak);
+ l1->tqsetAlignment(AlignLeft | WordBreak);
l1->setFixedWidth(400);
l1->setMinimumHeight(50);
tl->addWidget(l1, 0);
@@ -73,9 +73,9 @@ ModemSelector::ModemSelector(TQWidget *parent) : TQDialog(parent, 0, true) {
ok->setDefault(true);
ok->setEnabled(false);
cancel = bbox->addButton(KStdGuiItem::cancel());
- bbox->layout();
+ bbox->tqlayout();
tl->addWidget(bbox);
- setFixedSize(sizeHint());
+ setFixedSize(tqsizeHint());
// set up modem database
db = new ModemDatabase();
@@ -112,7 +112,7 @@ void ModemSelector::vendorSelected(int idx) {
model->clear();
model->insertStringList(*models);
- // FIXME: work around Qt bug
+ // FIXME: work around TQt bug
if(models->count() == 0)
model->update();
delete models;
@@ -152,7 +152,7 @@ TQStringList *ModemDatabase::models(TQString vendor) {
for(uint i = 0; i < modems.count(); i++) {
CharDict *dict = modems.at(i);
- if(dict->find("Vendor") != 0) {
+ if(dict->tqfind("Vendor") != 0) {
if(vendor == *(*dict)["Vendor"] && (*(*dict)["Name"]).at(0) != '!')
sl->append(*(*dict)["Name"]);
}
@@ -173,13 +173,13 @@ void ModemDatabase::loadModem(const TQString &key, CharDict &dict) {
map = modemDB->entryMap(key);
it = map.begin();
// remove parent attribute
dict.setAutoDelete(true);
dict.remove("Parent");
// e = it->current();
while(!it.key().isNull()) {
- if(dict.find(it.key()) == 0) {
+ if(dict.tqfind(it.key()) == 0) {
dict.insert(it.key(), new TQString(it.data()));
}
it++;
@@ -187,10 +187,10 @@ void ModemDatabase::loadModem(const TQString &key, CharDict &dict) {
// check name attribute
if(dict["Name"] == 0 || key[0]=='!') {
- dict.replace("Name", new TQString(key));
+ dict.tqreplace("Name", new TQString(key));
}
// check parent attribute
if(dict["Parent"] != 0)
loadModem(*dict["Parent"], dict);
else
@@ -217,16 +217,16 @@ void ModemDatabase::load() {
// if(strcmp(it->latin1(), "Common") == 0) {
if(*it == "Common") {
TQString s = i18n("Hayes(tm) compatible modem");
- c->replace("Name", new TQString (s));
+ c->tqreplace("Name", new TQString (s));
s = i18n("<Generic>");
- c->replace("Vendor", new TQString(s));
+ c->tqreplace("Vendor", new TQString(s));
}
modems.append(c);
if(modemDB->hasKey("Vendor")) {
TQString vendor = modemDB->readEntry("Vendor");
- if(lvendors->findIndex(vendor) == -1)
+ if(lvendors->tqfindIndex(vendor) == -1)
lvendors->append(vendor);
}
++it;
@@ -173,13 +173,13 @@ void ModemDatabase::loadModem(const TQString &key, CharDict &dict) {
map = modemDB->entryMap(key);
it = map.begin();
- // remove parent attribute
+ // remove tqparent attribute
dict.setAutoDelete(true);
dict.remove("Parent");
@@ -187,10 +187,10 @@ void ModemDatabase::loadModem(const TQString &key, CharDict &dict) {
}
- // check parent attribute
+ // check tqparent attribute
if(dict["Parent"] != 0)
loadModem(*dict["Parent"], dict);